@@ -25,3 +25,7 @@ class NoMemberError(RdError):
     An error that occurs when class member is called that does not exist.
     """
     pass
+
+
+class HandshakeError(RdError):
+    """Error is thrown when a handshake with a client fails."""
